@@ -35,6 +35,7 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib/gi18n.h>
+#include "gnome-scan-private.h"
 #include "gnome-scan-init.h"
 #include "gnome-scan-dialog.h"
 #include "gnome-scan-acquisition-dialog.h"
@@ -82,7 +83,6 @@ struct _GnomeScanDialogPrivate
 	gboolean		run;
 	
 	/* 	Widgets  */
-	GtkTooltips*		tooltips;
 	GtkWidget*		notebook;
 	
 	/* General */
@@ -256,9 +256,6 @@ gnome_scan_dialog_constructor (GType type, guint n, GObjectConstructParam *param
 						   GS_STOCK_SCAN,
 						   GTK_RESPONSE_APPLY);
 	
-	priv->tooltips = gtk_tooltips_new();
-	gtk_tooltips_enable (priv->tooltips);
-	
 	/* 	Notebook  */
 	priv->notebook = gtk_notebook_new ();
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (widget)->vbox), priv->notebook,
@@ -632,18 +629,9 @@ gsd_build_group_box (GnomeScanDialog *dialog, GtkWidget *page, GtkBox *box, Gnom
 		shows_label = gnome_scan_param_widget_shows_label (GNOME_SCAN_PARAM_WIDGET (widget));
 		box_expands = box_expands || expands;
 		
-		/* if widget does not have it's own GdkWindow, pack it in a GtkEventBox
-		 in order to enable tooltips */
-		if (GTK_WIDGET_NO_WINDOW (widget)) {
-			eventbox = gtk_event_box_new ();
-			gtk_container_add (GTK_CONTAINER (eventbox), widget);
-			widget = eventbox;
-		}
-		
-		gtk_tooltips_set_tip (priv->tooltips, widget,
-							  dgettext (gs_param_spec_get_domain (node->data),
-										g_param_spec_get_blurb (node->data)),
-							  NULL);
+		gtk_widget_set_tooltip_text (widget,
+									 dgettext (gs_param_spec_get_domain (node->data),
+											   g_param_spec_get_blurb (node->data)));
 		
 		gtk_widget_set_no_show_all (widget, FALSE);
 		gsd_add_to_box_show (group_box, 1);
@@ -667,15 +655,9 @@ gsd_build_group_box (GnomeScanDialog *dialog, GtkWidget *page, GtkBox *box, Gnom
 															  g_param_spec_get_nick (node->data))));
 			gtk_misc_set_alignment (GTK_MISC (label), 0., .5);
 			
-			/* pack label in an eventbox */
-			eventbox = gtk_event_box_new ();
-			gtk_container_add (GTK_CONTAINER (eventbox), label);
-			label = eventbox; /* substitute eventbox to label in the following code */
-			
-			gtk_tooltips_set_tip (priv->tooltips, label,
-								  dgettext (gs_param_spec_get_domain (node->data),
-											g_param_spec_get_blurb (node->data)),
-								  NULL);
+			gtk_widget_set_tooltip_text (label,
+										 dgettext (gs_param_spec_get_domain (node->data),
+												   g_param_spec_get_blurb (node->data)));
 			gtk_table_attach (GTK_TABLE (table), label,
 							  0, 1,
 							  count, count+1,
@@ -1055,6 +1037,7 @@ gsd_build_sink_ui (GnomeScanDialog *gsd)
 	
 	groups = gnome_scan_plugin_params_get_other_groups (GNOME_SCAN_PLUGIN (sink),
 														GS_PARAM_GROUP_SINK_FRONT,
+														GS_PARAM_GROUP_HIDDEN,
 														0);
 	for (node = groups; node ; node = node->next) {
 		gsd_build_group_box (gsd, priv->sink_page,
@@ -1144,6 +1127,7 @@ gsd_build_scanner_ui	(GnomeScanDialog *gsd)
 														GS_PARAM_GROUP_SCANNER_FRONT,
 														GS_PARAM_GROUP_PREVIEW,
 														GS_PARAM_GROUP_FORMAT,
+														GS_PARAM_GROUP_HIDDEN,
 														0);
 	
 	/* build each group in the advanced page */
@@ -1184,7 +1168,9 @@ gsd_build_processing_ui(GnomeScanDialog *gsd)
 	/* loop each processor and add options */
 	for (; proc; proc = proc->next) {
 		groups = gnome_scan_plugin_params_get_other_groups (GNOME_SCAN_PLUGIN (proc->data),
-															GS_PARAM_GROUP_PREVIEW, -1);
+															GS_PARAM_GROUP_PREVIEW,
+															GS_PARAM_GROUP_HIDDEN,
+															0);
 		for (node = groups; node ; node = node->next) {
 			gsd_build_group_box (gsd, priv->processing_page,
 								 GTK_BOX (priv->processing_box),
